SystemOrganization addCategory: #'Xpf-Tests-Server'!
SystemOrganization addCategory: #'Xpf-Tests-Server-Rest'!
SystemOrganization addCategory: #'Xpf-Tests-Client'!
SystemOrganization addCategory: #'Xpf-Tests-Server-Rfb'!

RestTest subclass: #XpfRestTest
	instanceVariableNames: 'testProject testUser testUser2 testTask projects users testStory testIteration'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Tests-Server-Rest'!

XpfRestTest subclass: #XpfModelToProxyTest
	instanceVariableNames: 'proxyProject testUser3 proxyUser proxyUser3 proxyIteration1 proxyIteration2 testIteration2 proxyStory cache'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Tests-Client'!

!XpfModelToProxyTest methodsFor: 'as yet unclassified' stamp: 'mt 4/21/2009 16:29'!
setUp

	| repository |
	super setUp.
	repository := XpfProxyRepository fromString: self class url.
	cache := repository cache.
	proxyProject := repository getAllProjects first.
	testUser3 := XpfUser addNewUser: (Dictionary with: 'login' -> 'unique').
	testProject attachDeveloper: testUser3.
	proxyUser := repository getAllUsers detect: [:user | user login = self class login2].
	proxyUser3 := repository getAllUsers detect: [:user | user login = testUser3 login].
	
	testIteration2 := XpfIteration new title: 'Test Iteration 2'.
	testProject addIteration: testIteration2.
	proxyIteration1 := proxyProject iterations first.
	proxyIteration2 := proxyProject iterations second.
	proxyStory := proxyIteration1 userStories first.! !

!XpfModelToProxyTest methodsFor: 'as yet unclassified' stamp: 'mfp 4/29/2009 15:50'!
testAddTaskToMovedUserStoryByAutomaticRedirect

	| oldRestUri oldTaskCount |
	oldRestUri := testStory restUri.
	oldTaskCount := testStory tasks size.
	testIteration2 addUserStory: testStory.
	self
		should: (cache includesKey: oldRestUri);
		shouldnt: (cache includesKey: testStory restUri);
		should: proxyStory restUri = oldRestUri.
	"implicit redirect with the next assertion"
	proxyStory addNewTask: (Dictionary with: 'title' ->'new task').
	self 
		should: testStory tasks size = (oldTaskCount + 1);
		should: testStory tasks last title = 'new task';
		should: proxyStory tasks size = (oldTaskCount + 1);
		should: proxyStory tasks last title = 'new task'.! !

!XpfModelToProxyTest methodsFor: 'as yet unclassified' stamp: 'mfp 4/29/2009 15:33'!
testDeleteMovedUserStoryByAutomaticRedirect

	| oldUserstoriesCount1 oldUserstoriesCount2 oldRestUri |
	oldRestUri := testStory restUri.
	oldUserstoriesCount1 := proxyIteration1 userStories size.
	oldUserstoriesCount2 := proxyIteration2 userStories size.
	testIteration2 addUserStory: testStory.
	self
		should: (cache includesKey: oldRestUri);
		shouldnt: (cache includesKey: testStory restUri);
		should: oldUserstoriesCount1 = 1;
		should: oldUserstoriesCount2 = 0;
		should: proxyStory restUri = oldRestUri.
	"implicit redirect with the next assertion"
	proxyStory delete.
	self 
		should: testStory isDeleted;
		should: proxyStory isDeleted;
		should: proxyIteration1 userStories isEmpty.! !

!XpfModelToProxyTest methodsFor: 'as yet unclassified' stamp: 'mfp 4/29/2009 15:29'!
testEditMovedUserStoryByAutomaticRedirect

	| oldUserstoriesCount1 oldUserstoriesCount2 oldRestUri |
	oldRestUri := testStory restUri.
	oldUserstoriesCount1 := proxyIteration1 userStories size.
	oldUserstoriesCount2 := proxyIteration2 userStories size.
	testIteration2 addUserStory: testStory.
	self
		should: (cache includesKey: oldRestUri);
		shouldnt: (cache includesKey: testStory restUri);
		should: oldUserstoriesCount1 = 1;
		should: oldUserstoriesCount2 = 0;
		should: proxyStory restUri = oldRestUri.
	"implicit redirect with the next assertion"
	proxyStory title: 'new title'.
	self 
		should: testStory title = 'new title';
		should: proxyStory title = 'new title'.! !

!XpfModelToProxyTest methodsFor: 'as yet unclassified' stamp: 'cs 4/25/2009 17:52'!
testReloadAddDeveloper

	| oldDeveloperCount oldProjectCount |
	oldDeveloperCount := proxyProject developers size.
	oldProjectCount := proxyUser projects size.
	testProject attachDeveloper: testUser2.
	self
		should: oldDeveloperCount = 2;
		should: oldProjectCount = 0.
	proxyProject repository reload.
	self
		should: proxyProject developers size = 3;
		should: proxyUser projects size = 1.! !

!XpfModelToProxyTest methodsFor: 'as yet unclassified' stamp: 'cs 4/26/2009 18:13'!
testReloadMoveUserStory

	| oldUserstoriesCount1 oldUserstoriesCount2 oldRestUri |
	oldRestUri := testStory restUri.
	oldUserstoriesCount1 := proxyIteration1 userStories size.
	oldUserstoriesCount2 := proxyIteration2 userStories size.
	testIteration2 addUserStory: testStory.
	self
		should: (cache includesKey: oldRestUri);
		shouldnt: (cache includesKey: testStory restUri);
		should: oldUserstoriesCount1 = 1;
		should: oldUserstoriesCount2 = 0.
	proxyStory reload.
	self
		shouldnt: (cache includesKey: oldRestUri);
		should: (cache includesKey: testStory restUri);
		should: proxyIteration1 userStories size = 0;
		should: proxyIteration2 userStories size = 1;
		should: proxyIteration2 userStories first id = testStory id.! !

!XpfModelToProxyTest methodsFor: 'as yet unclassified' stamp: 'mfp 4/29/2009 15:26'!
testReloadMovedUserStoryByAutomaticRedirect

	| oldUserstoriesCount1 oldUserstoriesCount2 oldRestUri |
	oldRestUri := testStory restUri.
	oldUserstoriesCount1 := proxyIteration1 userStories size.
	oldUserstoriesCount2 := proxyIteration2 userStories size.
	testIteration2 addUserStory: testStory.
	self
		should: (cache includesKey: oldRestUri);
		shouldnt: (cache includesKey: testStory restUri);
		should: oldUserstoriesCount1 = 1;
		should: oldUserstoriesCount2 = 0;
		should: proxyStory restUri = oldRestUri;
		"implicit reload with the next assertion"
		should: (proxyStory iteration = proxyIteration2);
		shouldnt: (cache includesKey: oldRestUri);
		should: (cache includesKey: testStory restUri);
		should: proxyIteration1 userStories size = 0;
		should: proxyIteration2 userStories size = 1;
		should: proxyIteration2 userStories first id = testStory id;
		should: (cache includesKey: testStory restUri);
		should: proxyStory restUri = testStory restUri.! !

!XpfModelToProxyTest methodsFor: 'as yet unclassified' stamp: 'cs 4/25/2009 17:20'!
testReloadRemoveDeveloper

	| oldDeveloperCount oldProjectCount |
	oldDeveloperCount := proxyProject developers size.
	oldProjectCount := proxyUser3 projects size.
	testProject detachDeveloper: testUser3.
	self
		should: oldDeveloperCount = 2;
		should: oldProjectCount = 1.
	proxyProject repository reload.
	self
		should: proxyProject developers size = 1;
		should: proxyUser3 projects size = 0.! !

!XpfModelToProxyTest methodsFor: 'as yet unclassified' stamp: 'mt 4/16/2009 16:47'!
testReloadTitle

	| oldTitle |
	oldTitle := testProject title.
	testProject title: 'Wow!!'.
	proxyProject repository reload.
	self should: proxyProject title = testProject title! !

!XpfModelToProxyTest methodsFor: 'as yet unclassified' stamp: 'mt 4/16/2009 16:49'!
testTitle

	self should: proxyProject title = testProject title.
	proxyProject iterations 
		with: testProject iterations
		do: [ :proxyIter :realIter | self should: proxyIter title = realIter title ]! !

XpfRestTest subclass: #XpfProxyTest
	instanceVariableNames: 'projectProxy iterationProxy'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Tests-Client'!

!XpfProxyTest methodsFor: 'as yet unclassified' stamp: 'mt 4/16/2009 16:49'!
setUp
	| factory |
	super setUp.
	factory := XpfProxyRepository fromString: self class url.
	projectProxy := factory getAllProjects first.
	iterationProxy := projectProxy iterations first! !

!XpfProxyTest methodsFor: 'as yet unclassified' stamp: 'mt 4/16/2009 16:54'!
testUpdateOnAdd

	| usCount us |
	usCount := testIteration userStories size.
	us := iterationProxy addNewUserStory: (Dictionary with: 'title' -> 'UpdateOnAddTask').
	self
		should: iterationProxy project = projectProxy;
		should: us iteration = iterationProxy;
		should: testIteration userStories size = (usCount + 1);
		should: iterationProxy userStories size = (usCount + 1).! !

XpfRestTest subclass: #XpfRestAuthTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Tests-Server-Rest'!

!XpfRestAuthTest methodsFor: 'as yet unclassified' stamp: 'mt 4/21/2009 14:55'!
testAuthentication

	"Try to get information about a project via http GET request.
	 Verify this by looking into the database directly."

	| response jsonResult |
	self should: XpfUser currentUser isNil.
	response := self get: 'projects/', testProject id asString request: self class auth.
	self
		should: response responseCode = 401;
		should: XpfUser currentUser isNil.
	
	response := self get: 'projects/', testProject id asString request: self class authUser2Pass.
	self should: response responseCode = 403.

	response := self get: 'projects/', testProject id asString request: self class authUserPass.
	self should: response responseCode = 200.

	jsonResult := Json readFrom: response content readStream.
	
 	self 
		should: testProject title = (jsonResult at: 'title');
		should: testProject id = (jsonResult at: 'id').! !

XpfRestTest subclass: #XpfRestResourceTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Tests-Server-Rest'!

!XpfRestResourceTest methodsFor: 'tests' stamp: 'mt 4/16/2009 13:42'!
testDeleteOneProject
	"Try to delete a project via http DELETE request. This operation should be idempotent. 
	Verify this by looking into the database directly."

	| projectCount response |
	projectCount := XpfProject all size.
	response := self delete: testProject restUri.
	
	self 
		should: response responseCode = 200;
		should: XpfProject all size = (projectCount - 1);
		shouldnt: (XpfProject all anySatisfy: [:aProject| aProject id = testProject id]).! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'mt 4/16/2009 13:41'!
testDeleteOneTask
	"Try to delete a task from testProject via http DELETE request.
	 This operation should be idempotent. Verify this by looking into the database directly."

	| taskCount response |
	taskCount := testStory tasks size.
	response := self delete: testTask restUri.
	
	self
		should: response responseCode = 200;
		should: testStory tasks size = (taskCount - 1);
		shouldnt: (testStory tasks anySatisfy: [:task| task id = testTask id]).! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'mt 4/16/2009 13:42'!
testDeleteOneUser
	"Try to delete a user via http DELETE request. This operation should be idempotent. 
	Verify this by looking into the database directly."

	| userCount response |
	userCount := XpfUser all size.
	response := self delete: testUser restUri.
	
	self 
		should: response responseCode = 200;
		should: XpfUser all size = (userCount - 1);
		shouldnt: (XpfUser all anySatisfy: [:aUser| aUser id = testUser id]).! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'mt 4/16/2009 13:44'!
testDeleteUserstoryWithThreeTasks
	"Try to delete a userStory from testProject via http DELETE request."

	| response storyCount |
	testStory addNewTask: (Dictionary newFrom: {'title' -> 'Test Task 2'}).
	testStory addNewTask: (Dictionary newFrom: {'title' -> 'Test Task 3'}).
	storyCount := testIteration userStories size.
	response := self delete: testStory restUri.
	self
		should: response responseCode = 200;
		should: testIteration userStories size = (storyCount - 1);
		should: testStory tasks size = 0.! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'mt 4/16/2009 13:44'!
testGetAllProjects
	"Try to get a list with rest urls to all projects via http GET request. 
	Verify this by looking into the database directly."

	| response jsonResult restUrl |
	response := self get: 'projects'.	
	self should: response responseCode = 200.
	
	jsonResult := Json readFrom: response content readStream.
	
	self should: XpfProject all size = jsonResult size.
	
	XpfProject all do: [:project |
		restUrl := project restUri.
		self should: (jsonResult includes: restUrl)].! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'mt 4/16/2009 13:46'!
testGetAllTasks
	"Try to get a list with rest urls to all tasks of testProject via http GET request.
	 Verify this by looking into the database directly."

	| response restUrl jsonResult|
	response := self get: ('{1}/tasks' format: {testStory restUri}).
	self should: response responseCode = 200.
	
	jsonResult := Json readFrom: response content readStream.
	self should: testStory tasks size = jsonResult size.
	
	testStory tasks do: [:task |
		restUrl := task restUri.
		self should: (jsonResult includes: restUrl)].! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'SR 4/16/2009 23:34'!
testGetAllTasksWithDeleted
	"Try to get a list with rest urls to all tasks of testProject via http GET request.
	 Verify this by looking into the database directly."

	| response restUrl jsonResult|
	testTask delete.
	response := self get: ('{1}/tasks/all' format: {testStory restUri}).
	self should: response responseCode = 200.
	
	jsonResult := Json readFrom: response content readStream.
	self
		should: testStory tasks size = (testStory tasksWithDeleted size - 1);
		should: testStory tasksWithDeleted size = jsonResult size.
	
	testStory tasksWithDeleted do: [:task |
		restUrl := task restUri.
		self should: (jsonResult includes: restUrl)].! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'mt 4/16/2009 13:47'!
testGetAllUsers
	"Try to get a list with rest urls to all users via http GET request. 
	Verify this by looking into the database directly."

	| response jsonResult restUrl |
	response := self get: 'users'.	
	self should: response responseCode = 200.
	
	jsonResult := Json readFrom: response content readStream.
	
	self should: XpfUser all size = jsonResult size.
	
	XpfUser all do: [:user |
		restUrl := user restUri.
		self should: (jsonResult includes: restUrl)].! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'cs 4/25/2009 17:08'!
testGetDeletedTaskDevelopers
	"Try to get information about the developers of a task from testProject
	 via http GET request. Verify this by looking into the database directly."

	| response jsonResult |
	testTask delete.
	response := self get: testTask restUri, '/developers'.
	self should: response responseCode = 200.
	
	jsonResult := Json readFrom: response content readStream.
	self should: testTask developers size = jsonResult size.
	testTask developers do: [:developer |
		self should: (jsonResult includes: developer restUri)].! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'cs 4/25/2009 17:04'!
testGetOneDeletedTask
	"Try to get information about a task from testProject via http GET request.
	 Verify this by looking into the database directly."

	| response jsonResult |
	testTask delete.
	response := self get: testTask restUri.
	self should: response responseCode = 200.
	
	jsonResult := Json readFrom: response content readStream.
	self
		should: testTask title = (jsonResult at: 'title');
		should: testTask id = (jsonResult at: 'id');
		should: testTask timeEstimated = (jsonResult at: 'timeEstimated');
		should: testTask timeActual = (jsonResult at: 'timeActual');
		should: testTask isDone = (jsonResult at: 'isDone');
		should: (testTask userStory restUri = (jsonResult at: 'ref userStory')).! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'cs 4/25/2009 17:06'!
testGetOneProject
	"Try to get information about a project via http GET request.
	 Verify this by looking into the database directly."

	| response jsonResult |	
	response := self get: 'projects/', testProject id asString.
	self should: response responseCode = 200.
	
	jsonResult := Json readFrom: response content readStream.
	
	self 
		should: testProject title = (jsonResult at: 'title');
		should: testProject id = (jsonResult at: 'id').! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'cs 4/27/2009 17:30'!
testGetOneProjectDepth2

	| response jsonResult |	
	response := self get: 'projects/', testProject id asString, '?depth=2'.
	self should: response responseCode = 200.
	
	jsonResult := Json readFrom: response content readStream.
	
	self 
		should: testProject title = (jsonResult at: 'title');
		should: testProject iterations size = (jsonResult at: 'col iterations') size.! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'cs 4/29/2009 14:40'!
testGetOneProjectDepth3

	| response jsonResult |	
	response := self get: 'projects/', testProject id asString, '?depth=3'.
	self should: response responseCode = 200.
	
	jsonResult := Json readFrom: response content readStream.
	
	self 
		should: testProject title = (jsonResult at: 'title');
		should: testProject iterations size = (jsonResult at: 'col iterations') size.
	1 to: testProject iterations size do: [:i | 
		self should:
			(testProject iterations at: i) title =
			(((jsonResult at: 'col iterations') at: i) at: 'title')]! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'cs 4/25/2009 17:00'!
testGetOneTask
	"Try to get information about a task from testProject via http GET request.
	 Verify this by looking into the database directly."

	| response jsonResult |
	response := self get: testTask restUri.
	self should: response responseCode = 200.
	
	jsonResult := Json readFrom: response content readStream.
	self
		should: testTask title = (jsonResult at: 'title');
		should: testTask id = (jsonResult at: 'id');
		should: testTask timeEstimated = (jsonResult at: 'timeEstimated');
		should: testTask timeActual = (jsonResult at: 'timeActual');
		should: testTask isDone = (jsonResult at: 'isDone');
		should: testTask userStory restUri = (jsonResult at: 'ref userStory').! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'cs 4/25/2009 17:07'!
testGetProjectDevelopers

	| response jsonResult |
	response := self get: testProject restUri, '/developers'.
	self should: response responseCode = 200.
	
	jsonResult := Json readFrom: response content readStream.
	self should: testProject developers size = jsonResult size.
	testProject developers do: [:developer |
		self should: (jsonResult includes: developer restUri)].! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'cs 4/25/2009 17:09'!
testGetProjectIterations

	| response jsonResult |
	response := self get: testProject restUri, '/iterations'.
	self should: response responseCode = 200.
	
	jsonResult := Json readFrom: response content readStream.
	self should: testProject iterations size = jsonResult size.
	
	1 to: testProject iterations size do: [:index |
		self should: (testProject iterations at: index) restUri = (jsonResult at: index)].! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'cs 4/27/2009 11:35'!
testGetStoryOneDeletedTask

	| response jsonResult response2 jsonResult2 oldTaskCount |
	oldTaskCount := testStory tasks size.
	testTask delete.
	response := self get: testStory restUri, '/tasks'.
	self should: response responseCode = 200.
	response2 := self get: testStory restUri, '/tasksWithDeleted'.
	self should: response2 responseCode = 200.
	
	jsonResult := Json readFrom: response content readStream.
	jsonResult2 := Json readFrom: response2 content readStream.
	self
		should: jsonResult size = (oldTaskCount - 1);
		should: jsonResult2 size = oldTaskCount.! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'cs 4/25/2009 17:07'!
testGetTaskDevelopers
	"Try to get information about the developers of a task from testProject
	 via http GET request. Verify this by looking into the database directly."

	| response jsonResult |
	response := self get: testTask restUri, '/developers'.
	self should: response responseCode = 200.
	
	jsonResult := Json readFrom: response content readStream.
	self should: testTask developers size = jsonResult size.
	testTask developers do: [:developer |
		self should: (jsonResult includes: developer restUri)].! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'mt 4/16/2009 13:52'!
testPostAddProject
	"Try to create a new project via http POST request. Verify this by looking into the database directly."

	| response projectCount newProject |
	projectCount := XpfProject all size.
	response := self post: 'projects' content: (self jsonDataFrom: {'title' -> 'new test project'}).

	self should: XpfProject all size = (projectCount + 1).

	newProject := XpfProject all detect: [:aProject | 
		aProject id = response content asURI pathComponents last asNumber].
	self 
		should: newProject title = 'new test project';
		should: response content = newProject restUri! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'mt 4/16/2009 14:55'!
testPostAddTask
	"Try to create a new task to testProject via http POST request.
	 Verify this by looking into the database directly."
	
	| response tasksCount newTask |
	self flag: #CreateFixtures.
	tasksCount := testStory tasks size.
	response := self
		post: ('{1}/tasks' format: {testStory restUri})
		content: (self jsonDataFrom: {'title' -> 'new test task'. 'timeEstimated' -> 42}).
	
	self should: response responseCode = 200.
	
	response := response content.
	
	self should: testStory tasks size = (tasksCount + 1).
	
	newTask := testStory tasks detect:
		[:task | task id = response asURI pathComponents last asNumber].
	
	self
		should: response = newTask restUri;
		should: newTask title = 'new test task';
		should: newTask timeEstimated = 42;
		should: newTask userStory = testStory.! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'mt 4/16/2009 13:55'!
testPostAddUser
	"Try to create a new user via http POST request. Verify this by looking into the database directly."

	| response userCount newUser |
	userCount := XpfUser all size.
	response := self
		post: 'users'
		content: (self jsonDataFrom: {'userName' -> 'New User'. 'login' -> 'new.user@email.de'. 'password' -> nil}).

	self should: XpfUser all size = (userCount + 1).

	newUser := XpfUser all detect: [:aProject | 
		aProject id = response content asURI pathComponents last asNumber].
	self 
		should: newUser userName = 'New User';
		should: newUser login = 'new.user@email.de';
		should: response content = newUser restUri.! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'mt 4/16/2009 13:57'!
testPostAttachDeveloperToProject
	"Try to attach testUser to testProject via http POST request"
	
	| response developersCount |
	developersCount := testProject developers size.
	response := self
		post: ('{1}/developers' format: {testProject restUri})
		content: ('"{1}"' format: {testUser2 restUri}).
	
	self 
		should: response responseCode = 200;
		should: testProject developers size = (developersCount + 1);
		should: (testProject developers includes: testUser2);
		should: response content = testUser2 restUri.! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'mt 4/16/2009 13:58'!
testPostAttachDeveloperToTask
	"Try to attach testUser to testTask via http POST request.
	 Verify this by looking into the database directly."
	
	| response developersCount |
	developersCount := testTask developers size.
	response := self
		post: ('{1}/developers' format: {testTask restUri})
		content: ('"{1}"' format: {testUser restUri}).
	
	self 
		should: response responseCode = 200;
		should: testTask developers size = (developersCount + 1);
		should: (testTask developers includes: testUser);
		should: response content = testUser restUri.! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'mt 4/16/2009 14:00'!
testPutOneProject
	"Try to update information for a project via http PUT request.
	 This operation should be idempotent. Verify this by looking into the database directly."
	
	| projectCount response iterCount developersCount |
	projectCount := XpfProject all size.
	iterCount := testProject iterations size.
	developersCount := testProject developers size.
	
	2 timesRepeat: [	
		response := self
			put: testProject restUri
			content: (self jsonDataFrom: {'title' -> 'New Title'}).
			
		self 
			should: response responseCode = 200;
			should: XpfProject all size = projectCount;
			should: testProject title = 'New Title';
			should: testProject iterations size = iterCount;
			should: testProject developers size = developersCount].! !

!XpfRestResourceTest methodsFor: 'tests' stamp: 'mt 4/16/2009 14:02'!
testPutOneTask
	"Try to update information for a task of testProject via http PUT request.
	 This operation should be idempotent. Verify this by looking into the database directly."
	
	| taskCount response developersCount |
	self flag: #CreateFixtures.
	taskCount := testStory tasks size.
	developersCount := testTask developers size.
	
	2 timesRepeat: [
		response := self
			put: testTask restUri
			content: (self jsonDataFrom: {
				'title' -> 'New Title'.
				'timeEstimated' -> 25.
				'timeActual' -> 50.
				'isDone' -> true}).
			
		self 
			should: response responseCode = 200;
			should: testStory tasks size = taskCount;
			should: testTask title = 'New Title';
			should: testTask timeEstimated = 25;
			should: testTask timeActual = 50;
			should: testTask userStory = testStory;
			should: testTask developers size = developersCount;
			should: testTask isDone].! !

!XpfRestTest class methodsFor: 'testing' stamp: 'topa 3/5/2009 13:08'!
isAbstract
	
	^ self == XpfRestTest
! !

!XpfRestTest methodsFor: 'actions' stamp: 'mt 3/12/2009 13:10'!
backup

	XpfProject useTestData: true.
	XpfUser useTestData: true.
	
	XpfProject projects: Set new.
	XpfUser users: Set new.! !

!XpfRestTest methodsFor: 'actions' stamp: 'mt 3/12/2009 13:10'!
restore

	XpfProject useTestData: false.
	XpfUser useTestData: false.! !

!XpfRestTest methodsFor: 'running' stamp: 'cs 4/27/2009 16:34'!
setUp
	"Install a handler for http service. Add a test project to the database."

	super setUp.
	self backup.
	XpfService installHandlers.

	testUser := XpfUser new
		login: self class login;
		password: self class password;
		wasOnline: true;
		lastAccess: TimeStamp now. 
	testUser2 := XpfUser new login: self class login2; password: self class password.

	testProject := XpfProject new title: 'Test Project'.
	testIteration := XpfIteration new title: 'Test Iteration'.
	testStory := XpfUserStory new title: 'Test UserStory'.
	testTask := XpfTask new
				title: 'Test Task';
				timeEstimated: 12;
				timeActual: 15.
	XpfProject addProject: testProject.
	XpfUser addUser: testUser.
	XpfUser addUser: testUser2.
	testProject addIteration: testIteration.
	testIteration addUserStory: testStory.
	testStory addTask: testTask.
	testProject attachDeveloper: testUser.! !

!XpfRestTest methodsFor: 'running' stamp: 'mt 4/3/2009 11:10'!
tearDown

	self restore.
	super tearDown.
	
	XpfUser currentUser: nil.
! !

XpfRestTest subclass: #XpfRevisionHandlerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Tests-Server-Rest'!

!XpfRevisionHandlerTest methodsFor: 'as yet unclassified' stamp: 'mig 4/1/2009 16:02'!
testChanges

	| response changes localRevisions |
	localRevisions := Dictionary new
		at: testUser restUri put: testUser revision;
		at: testUser2 restUri put: testUser2 revision;
		yourself.
	testUser2 login: self class login3.
	response := self post: '/changes' content: (Json render: localRevisions).
	self should: response isOk.
	changes := Json readFrom: response content readStream.
	self should: changes size = 1.
	self should: changes first = testUser2 restUri.! !

!XpfRevisionHandlerTest methodsFor: 'as yet unclassified' stamp: 'mig 4/1/2009 16:07'!
testDeletedChanges

	| response changes localRevisions restUri |
	localRevisions := Dictionary new
		at: testUser restUri put: testUser revision;
		at: testUser2 restUri put: testUser2 revision;
		yourself.
	restUri := testUser2 restUri.
	testUser2 delete.
	response := self post: '/changes' content: (Json render: localRevisions).
	self should: response isOk.
	changes := Json readFrom: response content readStream.
	self should: changes size = 1.
	self should: changes first = restUri.! !

!XpfRevisionHandlerTest methodsFor: 'as yet unclassified' stamp: 'mig 4/1/2009 15:55'!
testNoChanges

	| response changes localRevisions |
	localRevisions := Dictionary new
		at: testUser restUri put: testUser revision;
		at: testUser2 restUri put: testUser2 revision;
		yourself.
	response := self post: '/changes' content: (Json render: localRevisions).
	self should: response isOk.
	changes := Json readFrom: response content readStream.
	self should: changes isEmpty.! !

XpfRestTest subclass: #XpfRfbTunnelHttpHandlerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Tests-Server-Rfb'!

!XpfRfbTunnelHttpHandlerTest methodsFor: 'as yet unclassified' stamp: 'bs 4/17/2009 15:43'!
setUp
	super setUp.
	XpfRfbTunnelHttpHandler initialize.! !

!XpfRfbTunnelHttpHandlerTest methodsFor: 'as yet unclassified' stamp: 'bs 4/17/2009 15:20'!
tearDown
	super tearDown.
	XpfRfbTunnelHttpHandler initialize.! !

!XpfRfbTunnelHttpHandlerTest methodsFor: 'as yet unclassified' stamp: 'bs 4/27/2009 13:03'!
testAssigningAndFreeingPorts
	| firstPort portA portB testDuration freePort openedServices serviceA serviceB |
	openedServices := OrderedCollection new.
	[
	testDuration := Duration milliSeconds: 10. 
	XpfRfbTunnelHttpHandler pendingTime: testDuration.
	
	firstPort := XpfRfbTunnelHttpHandler firstPort.
	portA := XpfRfbTunnelHttpHandler assignAvailablePortTo: 'a'.
	self assert: [firstPort == portA]. 
	serviceA := HttpService startOn: portA.
	openedServices add: serviceA.
	
	(Delay forDuration: (testDuration * 2)) wait.
	
	portB := XpfRfbTunnelHttpHandler assignAvailablePortTo: 'b'.
	self assert: [(firstPort + 1) == portB].
	serviceB := HttpService startOn: portB.
	openedServices add: serviceB.
	
	(Delay forDuration: (testDuration * 2)) wait.
	
	serviceA unregister.
	self assert: [(firstPort) == (XpfRfbTunnelHttpHandler assignAvailablePortTo: 'a')].
	
	freePort := XpfRfbTunnelHttpHandler assignAvailablePortTo: 'c'.
	self assert: [(firstPort + 2) == freePort] description: ('should: {1}; was: {2}' format: {firstPort + 2. freePort}).
	
	serviceB unregister.
	self assert: [(firstPort + 1) == (XpfRfbTunnelHttpHandler assignAvailablePortTo: 'b')].
	
	] ensure: [ 
		openedServices do: [:aService | aService isRunning ifTrue: [aService unregister]]
	].
	! !

!XpfRfbTunnelHttpHandlerTest methodsFor: 'as yet unclassified' stamp: 'bs 4/27/2009 13:03'!
testFreeingAfterPendingTime
	| firstPort freePort testDuration |
	
	testDuration := Duration milliSeconds: 10. 
	XpfRfbTunnelHttpHandler pendingTime: testDuration.
	
	firstPort := XpfRfbTunnelHttpHandler firstPort.
	
	freePort := (XpfRfbTunnelHttpHandler assignAvailablePortTo: 'c').
	self assert: [firstPort == freePort] description: ('should: {1}; was: {2}' format: {firstPort. freePort}).
	(Delay forDuration: (testDuration * 2)) wait.
	
	freePort := (XpfRfbTunnelHttpHandler assignAvailablePortTo: 'c').
	self assert: [firstPort == freePort] description: ('should: {1}; was: {2}' format: {firstPort. freePort}).
	
	! !

!XpfRfbTunnelHttpHandlerTest methodsFor: 'as yet unclassified' stamp: 'bs 4/17/2009 16:08'!
testGetRequest
	| response |
	response := self get: 'rfb' request: self class authUserPass.
	self should: response responseCode = 200.
	self should: response content asInteger = XpfRfbTunnelHttpHandler firstPort.! !

!XpfRfbTunnelHttpHandlerTest methodsFor: 'as yet unclassified' stamp: 'bs 4/27/2009 13:04'!
testSameUserSamePort
	| firstPort testDuration |
	
	testDuration := Duration milliSeconds: 1. 
	XpfRfbTunnelHttpHandler pendingTime: testDuration.
	
	firstPort := XpfRfbTunnelHttpHandler firstPort.
	
	self assert: [firstPort == (XpfRfbTunnelHttpHandler assignAvailablePortTo: 'a')].
	self assert: [firstPort == (XpfRfbTunnelHttpHandler assignAvailablePortTo: 'a')].! !

TestCase subclass: #SSHTunnelTest
	instanceVariableNames: 'sut sut2 echoProcess'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Tests-Client'!

!SSHTunnelTest methodsFor: 'as yet unclassified' stamp: 'SR 4/28/2009 10:00'!
echoServer

   | server socketStream socket data |
   Socket initializeNetwork.
   [server := Socket newTCP.
   server listenOn: 7000 backlogSize: 4.
   2 timesRepeat: 
      [ 
      socket := server waitForAcceptFor: 60.
      socketStream := SocketStream on: socket.
      [socket notNil and: [socketStream isConnected]] whileTrue: 
         [data := socketStream upToAll: String crlf.
         socketStream
            nextPutAll: data;
            crlf;
            flush].
      socket notNil
         ifTrue:[socket closeAndDestroy]]]
   ensure:
      [server closeAndDestroy].! !

!SSHTunnelTest methodsFor: 'as yet unclassified' stamp: 'mig 4/28/2009 14:59'!
sendAndWaitReply
	
	^ Socket
		pingPorts: #(7001)
		on: '127.0.0.1'
		timeOutSecs: 20.
! !

!SSHTunnelTest methodsFor: 'as yet unclassified' stamp: 'mig 4/28/2009 14:58'!
setUp
	
	super setUp.
	sut := SSHTunnel new.
	sut2 := SSHTunnel new.
	echoProcess := [self echoServer] fork.! !

!SSHTunnelTest methodsFor: 'as yet unclassified' stamp: 'mig 4/28/2009 14:59'!
tearDown
	
	echoProcess terminate.
	super tearDown.! !

!SSHTunnelTest methodsFor: 'as yet unclassified' stamp: 'mig 4/28/2009 14:59'!
testSSHTunnelWithDefaultServer

	sut localPort: 7000.
	sut remotePort: 7002.
	
	sut2 isLocalTunnel: true.
	sut2 remotePort: 7002.
	sut2 localPort: 7001.
	
	sut execute.
	sut2 execute.

	(0 to: 10) 
		do: [:ignore | (Delay forMilliseconds: 600) wait]
		displayingProgress: 'Giving SSH connection some time...'. 
	
	self sendAndWaitReply.
	
	sut2 terminate.
	sut terminate.! !

TestCase subclass: #XpfClientTestCase
	instanceVariableNames: 'users projects'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Tests-Client'!

XpfClientTestCase subclass: #XpfChangePasswordTest
	instanceVariableNames: 'user sut'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Tests-Client'!

!XpfChangePasswordTest methodsFor: 'as yet unclassified' stamp: 'mt 3/31/2009 14:48'!
setUp

	super setUp.
	user := XpfUser newFrom:
		(Dictionary newFrom:
			{'login' -> 'bernd'.
			'password' -> 'secret'}).
	sut := XpfChangePasswordModel new.	
	sut user: user.! !

!XpfChangePasswordTest methodsFor: 'as yet unclassified' stamp: 'mt 3/31/2009 14:48'!
testChangePassword

	sut newPassword: 'delta'.
	sut newPasswordRepeat: 'delta'.
	sut accept.
	self should: (user authenticateBy: 'delta').! !

!XpfChangePasswordTest methodsFor: 'as yet unclassified' stamp: 'mt 3/31/2009 14:49'!
testInvalidRepeatPassword

	sut newPassword: 'delta'.
	sut newPasswordRepeat: 'delta23'.
	sut accept.
	self
		shouldnt: (user authenticateBy: 'delta');
		shouldnt: (user authenticateBy: 'delta23').! !

XpfClientTestCase subclass: #XpfClientTest
	instanceVariableNames: 'project iteration1 userstory1 userstory2 sut task1'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Tests-Client'!

!XpfClientTest methodsFor: 'running' stamp: 'mt 3/31/2009 16:14'!
setUp

	super setUp.
	self setupFixtures.
	sut := XpfClient new model: project.
! !

!XpfClientTest methodsFor: 'running' stamp: 'mt 4/16/2009 16:32'!
setupFixtures

	project := XpfProject new title: 'Test Project'.
	iteration1 := XpfIteration new
		title: 'Sample Iteration'.
	userstory1 := XpfUserStory new
		title: 'Test User Story with long title.'.
	userstory2 := XpfUserStory new title: 'Test User Story'.
	task1 := XpfTask new 
		title: 'Test Task'.
	project addIteration: iteration1.
	iteration1
		addUserStory: userstory1;
		addUserStory: userstory2.
	userstory1 addTask: task1.! !

!XpfClientTest methodsFor: 'running' stamp: 'mt 4/16/2009 11:06'!
tearDown

	userstory1 delete.
	userstory2 delete.
		
	super tearDown.! !

!XpfClientTest methodsFor: 'tests' stamp: 'mt 4/28/2009 15:04'!
testAddTask

	| sut2 taskCount taskMorphCount|
	sut2 := XpfTasksContent forModel: userstory1 tasks.
	taskCount := userstory1 tasks size.
	taskMorphCount :=  sut2 taskList submorphs size.

	self should: (sut2 taskList submorphs first isKindOf: XpfTaskMorph).

	userstory1 addNewTask: (Dictionary newFrom: {'title' -> 'Please enter descr...'}).
	sut2 taskList model: userstory1 tasks.

	self
		should: sut2 taskList submorphs size = (taskMorphCount + 1);
		should: (sut2 taskList submorphs first isKindOf: XpfTaskMorph);
		should: (sut2 taskList submorphs second isKindOf: XpfTaskMorph);
		should: userstory1 tasks size = (taskCount + 1).! !

!XpfClientTest methodsFor: 'tests' stamp: 'topa 4/22/2009 15:57'!
testAddUSMorphsToProjectMorph

	| usMorphCount projectMorph |
	projectMorph := XpfUserStoryPoolMorph new.
	usMorphCount := projectMorph userStorySubmorphs size.

	projectMorph addMorph: (XpfUserStoryMorph forUserStory: userstory1).
	self should: projectMorph userStorySubmorphs size = (usMorphCount + 1)! !

!XpfClientTest methodsFor: 'tests' stamp: 'topa 3/4/2009 00:32'!
testProjectTitleDisplay

 	self should: sut label = project printString.! !

!XpfClientTest methodsFor: 'tests' stamp: 'topa 4/21/2009 17:10'!
testTitleShouldNotBeTextInModel

	| sut2 oldContent newContent |
	sut2 := XpfUserStoryTitleContent forModel: userstory1.
	sut2 toggleEditMode.
	oldContent := sut2 title getText.
	newContent := Text fromString: 'This is a Text'.

	sut2 title setText: newContent.
	
	self shouldnt: userstory1 title isText.
	
	sut2 title setText: oldContent.
	sut2 toggleEditMode.! !

!XpfClientTest methodsFor: 'tests' stamp: 'cs 4/15/2009 16:45'!
testUserStoryTextContent
	| sut2 titleMorph |
	sut2 := XpfUserStoryMorph forUserStory: userstory2.
	self should: sut2 submorphCount > 0.
	titleMorph := (sut2 submorphs detect: 
		[:submorph | submorph submorphs anySatisfy:
			[:inner | inner isXpfUserStoryTitleContent]]) 
		submorphs first titleEdit.
	self
		shouldnt: titleMorph isNil;
		should: titleMorph getText asString = ('{1}' format: {userstory2 title});
		should: titleMorph width <= XpfUserStoryTitleContent defaultExtent x! !

!XpfClientTestCase class methodsFor: 'testing' stamp: 'mig 4/28/2009 18:05'!
isAbstract

 	^ self = XpfClientTestCase! !

!XpfClientTestCase methodsFor: 'test-helper' stamp: 'mig 4/28/2009 18:04'!
checkAccessor: aSelector on: aTargetObject with: anObject
	"test getter/setter aSelector of aTargetObject with anObject"
	
	aTargetObject perform: aSelector asMutator with: anObject.
	self should: (aTargetObject perform: aSelector) = anObject
		! !

!XpfClientTestCase methodsFor: 'test-helper' stamp: 'mig 4/28/2009 18:04'!
denyAccessor: aSelector on: aTargetObject with: anObject
	"test getter/setter aSelector of aTargetObject with anObject
	 that dont behave like plain accessors.
	"
	self
		shouldnt: (aTargetObject perform: aSelector) == anObject
		! !

!XpfClientTestCase methodsFor: 'running' stamp: 'mig 4/28/2009 18:04'!
setUp

	super setUp.
	
	XpfProject useTestData: true.
	XpfUser useTestData: true.
	
	XpfProject projects: Set new.
	XpfUser users: Set new.! !

!XpfClientTestCase methodsFor: 'running' stamp: 'mig 4/28/2009 18:04'!
tearDown
	
	XpfProject useTestData: false.
	XpfUser useTestData: false.
	
	super tearDown.! !

XpfClientTestCase subclass: #XpfHistoryTest
	instanceVariableNames: 'project userStory task sut iteration'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Tests-Client'!

!XpfHistoryTest methodsFor: 'running' stamp: 'mt 4/16/2009 16:35'!
setUp

	super setUp.
	project := XpfProject addNewProject: (Dictionary with: 'title' -> 'bla').
	iteration := project addIteration: (XpfIteration new title: 'testiteration').
	userStory := iteration addNewUserStory: (Dictionary with: 'title' -> 'blub').
	task := userStory addNewTask: (Dictionary with: 'title' -> 'brum').
	sut := XpfHistoryModel new.
	sut project: project.! !

!XpfHistoryTest methodsFor: 'tests' stamp: 'cs 4/8/2009 11:27'!
testAllSelected

	sut showProject: true.
	sut showUserStories: true.
	sut showTasks: true.
	self shouldnt: sut entries isEmpty.
	self should: sut entries size =
		(project history size +
		userStory history size +
		task history size).! !

!XpfHistoryTest methodsFor: 'tests' stamp: 'cs 4/8/2009 11:13'!
testNothingSelected

	sut showProject: false.
	sut showUserStories: false.
	sut showTasks: false.
	self should: sut entries isEmpty.! !

!XpfHistoryTest methodsFor: 'tests' stamp: 'cs 4/8/2009 11:27'!
testProjectSelected

	sut showProject: true.
	sut showUserStories: false.
	sut showTasks: false.
	self shouldnt: sut entries isEmpty.
	self should: sut entries size = project history size.! !

!XpfHistoryTest methodsFor: 'tests' stamp: 'cs 4/8/2009 11:27'!
testTasksSelected

	sut showProject: false.
	sut showUserStories: false.
	sut showTasks: true.
	self shouldnt: sut entries isEmpty.
	self should: sut entries size = task history size.! !

!XpfHistoryTest methodsFor: 'tests' stamp: 'cs 4/8/2009 11:28'!
testUserStoriesSelected

	sut showProject: false.
	sut showUserStories: true.
	sut showTasks: false.
	self shouldnt: sut entries isEmpty.
	self should: sut entries size = userStory history size.! !

XpfClientTestCase subclass: #XpfLoginTest
	instanceVariableNames: 'oldServer oldUser oldPassword'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Tests-Client'!

!XpfLoginTest methodsFor: 'running' stamp: 'topa 4/28/2009 15:11'!
setUp

	super setUp.
	oldServer := XpfLoginModel defaultServer.
	oldUser := XpfLoginModel defaultUser.
	oldPassword := 	XpfLoginModel defaultPassword.! !

!XpfLoginTest methodsFor: 'running' stamp: 'topa 4/28/2009 15:11'!
tearDown

	XpfLoginModel defaultServer: oldServer.
	XpfLoginModel defaultUser: oldUser.
	XpfLoginModel defaultPassword: oldPassword.
	super tearDown.
! !

!XpfLoginTest methodsFor: 'tests' stamp: 'topa 4/3/2009 16:56'!
testLoginDialog

	| dlg |
	dlg := XpfLogin new.
	
	dlg serverEntry setText: 'example.com'.
	dlg loginEntry setText: 'random.guy@web.de'.
	dlg passwordEntry setText: 'secret'.
	
	dlg connectButton performAction.
	
	self
		should: dlg result = 'http://random.guy%40web.de:secret@example.com:8082/'! !

TestCase subclass: #XpfTestCase
	instanceVariableNames: 'users projects'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Tests-Server'!

XpfTestCase subclass: #XpfAuthTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Tests-Server'!

!XpfAuthTest methodsFor: 'as yet unclassified' stamp: 'mfp 3/6/2009 11:04'!
testUsuallyAllowed
	| entity user |
	entity := XpfEntity new.
	user := XpfUser new.
	
	self should: (entity isMethod: 'METHOD' allowedFor: user).! !

XpfTestCase subclass: #XpfIterationTest
	instanceVariableNames: 'testProject sut'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Tests-Server'!

!XpfIterationTest methodsFor: 'running' stamp: 'mt 4/16/2009 11:50'!
setUp

	super setUp.
	testProject := XpfProject addNewProject: (Dictionary newFrom: {'title' -> 'testProject'}).
	sut := XpfIteration new 						
		title: 'Iteration 1'.! !

!XpfIterationTest methodsFor: 'tests' stamp: 'mt 4/16/2009 11:10'!
testAttributes

	self
		checkAccessor: #title on: sut with: 'Iteration 2';
		checkAccessor: #timeIdeal on: sut with: 15.
		
! !

!XpfIterationTest methodsFor: 'tests' stamp: 'mt 4/16/2009 15:30'!
testHasUserStories

	| iterationCount usCount us |
	testProject addIteration: sut.
	iterationCount := testProject iterations size.
	usCount := sut userStories size.
	us := sut addUserStory: XpfUserStory new.
	
	self
		should: sut userStories size = (usCount + 1)
			description: 'User story count for interation is invalid.';
		should: sut userStoriesWithDeleted size = (usCount + 1);
		should: testProject iterations size = iterationCount;
		should: (us iteration = sut).	
	
	us delete.
	self
		should: sut userStories size = usCount;
		should: sut userStoriesWithDeleted size = (usCount + 1);		
		should: testProject iterations size = iterationCount.

	sut delete.! !

!XpfIterationTest methodsFor: 'running' stamp: 'mt 4/16/2009 11:50'!
testMoveUserStory

	| targetIter us |
	testProject addIteration: sut.
	targetIter := testProject addIteration: XpfIteration new.
	us := sut addUserStory: (XpfUserStory new title: 'testMoveUserStory').
	
	self
		should: targetIter userStories isEmpty;
		should: sut userStories first = us.
		
	targetIter addUserStory: us.
	
	self
		should: targetIter userStories first = us;
		should: sut userStories isEmpty.
	! !

!XpfIterationTest methodsFor: 'tests' stamp: 'mt 4/16/2009 11:34'!
testNewAndDelete

	| oldCount us |
	oldCount := testProject iterations size.
	testProject addIteration: sut.
	us := sut addUserStory: XpfUserStory new.
	
	self
		should: testProject iterations size = (oldCount + 1);
		should: (testProject iterations anySatisfy: [:each | each title = sut title]);
		shouldnt: sut isDeleted;
		shouldnt: us isDeleted.

	sut delete.
	self 
		should: testProject iterations size = oldCount;
		should: sut isDeleted;
		should: us isDeleted.! !

!XpfIterationTest methodsFor: 'tests' stamp: 'SR 3/20/2009 21:38'!
testNewFrom

	[XpfIteration newFrom: Dictionary new.]
		on: Error
		do: [self fail].! !

XpfTestCase subclass: #XpfProjectChooserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Tests-Client'!

!XpfProjectChooserTest methodsFor: 'tests' stamp: 'SR 3/10/2009 14:19'!
testChooserDialog

	| liste sut |
	liste := {XpfProject new title:'1'. XpfProject new title: '2'}.
	sut := XpfProjectChooser new.
	sut model projects: liste.
	sut model projectsModel selectionIndex: 1.
	sut okButton performAction.
	
	self
		should: sut result = (liste at: 1).! !

XpfTestCase subclass: #XpfProjectTest
	instanceVariableNames: 'testUser sut testIteration'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Tests-Server'!

!XpfProjectTest methodsFor: 'running' stamp: 'mt 4/16/2009 13:22'!
setUp

	super setUp.
	sut := XpfProject new title: 'testProject'.
	testIteration := XpfIteration new title: 'testIteration'.
	testUser := XpfUser new
			login: 'christopher.schuster@student.hpi.uni-potsdam.de';
			userName: 'Christopher Schuster'.
	XpfUser addUser: testUser.! !

!XpfProjectTest methodsFor: 'tests' stamp: 'mt 4/16/2009 13:10'!
testAddExistingUserAsDeveloper
	"Add a user as developer to a project. That user should exist."

	| developerCount userCount developer userId |
	XpfUser addUser: testUser.
	userId := testUser id.
	developerCount := sut developers size.
	userCount := XpfUser all size.
	developer := sut attachDeveloper: testUser.

	self
		should: testUser id = userId;
		should: XpfUser all size = userCount;
		should: sut developers size = (developerCount + 1);
		should: (XpfUser all includes: developer);
		should: (sut developers includes: developer).

	sut detachDeveloper: developer.
	self
		should: testUser id = userId;
		should: XpfUser all size = userCount;
		should: sut developers size = developerCount;
		should: (XpfUser all includes: developer);
		shouldnt: (sut developers includes: developer).! !

!XpfProjectTest methodsFor: 'tests' stamp: 'topa 3/3/2009 23:40'!
testAttributes

	self checkAccessor: #title on: sut with: 'testProject'.! !

!XpfProjectTest methodsFor: 'tests' stamp: 'mt 4/16/2009 13:09'!
testAuthentication

	self shouldnt: (sut isMethod: 'GET' allowedFor: testUser).

	sut attachDeveloper: testUser.
	self should: (sut isMethod: 'GET' allowedFor: testUser).

	sut detachDeveloper: testUser.
	self shouldnt: (sut isMethod: 'GET' allowedFor: testUser).
	! !

!XpfProjectTest methodsFor: 'tests' stamp: 'mt 4/16/2009 15:38'!
testHasDevelopers

	| developerCount userCount developer |
	developerCount := sut developers size.
	userCount := XpfUser all size.
	developer := sut attachDeveloper: testUser.

	self
		should: testUser id notNil;
		should: XpfUser all size = userCount;
		should: sut developers size = (developerCount + 1);
		should: sut developersWithDeleted size = (developerCount + 1);
		should: (XpfUser all includes: developer);
		should: (sut developers includes: developer).

	sut detachDeveloper: developer.
	self
		should: XpfUser all size = userCount;
		should: sut developers size = developerCount;
		should: sut developersWithDeleted size = developerCount;
		should: (XpfUser all includes: developer);
		shouldnt: (sut developers includes: developer).! !

!XpfProjectTest methodsFor: 'tests' stamp: 'mt 4/16/2009 15:31'!
testHasIterations

	| iterCount iter |
	iterCount := sut iterations size.
	iter := sut addIteration: testIteration.

	self
		should: testIteration id notNil;
		should: sut iterations size = (iterCount + 1);
		should: sut iterationsWithDeleted size = (iterCount + 1).

	iter delete.
	self
		should: sut iterations size = iterCount;
		should: sut iterationsWithDeleted size = (iterCount + 1).! !

!XpfProjectTest methodsFor: 'tests' stamp: 'mt 4/16/2009 11:36'!
testNewAndDelete

	| oldCount |
	oldCount := XpfProject all size.
	XpfProject addProject: sut.
	sut addIteration: testIteration.
		
	self 
		should: XpfProject all size = (oldCount + 1) description: 'Project count is not valid for database.';
		should: (XpfProject all anySatisfy: [ :each | each title = sut title]);
		shouldnt: sut isDeleted;
		shouldnt: testIteration isDeleted.
	
	sut delete.
	self
		should: XpfProject all size = oldCount description: 'Project count is not valid for database after deletion.';
		should: sut isDeleted;
		should: testIteration isDeleted.! !

!XpfProjectTest methodsFor: 'tests' stamp: 'mt 3/16/2009 11:04'!
testNewFrom

	| done |
	[XpfProject newFrom: (Dictionary newFrom: {'title'->'testProject'}).]
		on: Error
		do: [self fail].
	
	[XpfProject newFrom: Dictionary new. done := true]
		on: Error
		do: [done := false].

	self shouldnt: done.! !

XpfTestCase subclass: #XpfRevisionTest
	instanceVariableNames: 'sut'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Tests-Server'!

!XpfRevisionTest methodsFor: 'running' stamp: 'topa 4/2/2009 18:39'!
setUp

	super setUp.
	sut := XpfProject new title: 'testProject'.! !

!XpfRevisionTest methodsFor: 'running' stamp: 'cs 4/24/2009 15:35'!
testHistorySerialization

	| entity parsedEntity |
	entity := XpfProject new.
	entity historyAddEntry: #changed for: #title from: 'foo' to: 'bar'.
	
	parsedEntity := Json readFrom: (Json render: entity history) readStream.
	
	self
		should: (parsedEntity isKindOf: Array);
		should: parsedEntity size = 2.! !

!XpfRevisionTest methodsFor: 'tests' stamp: 'topa 4/2/2009 18:40'!
testRevisionChange

	| oldRevision |
	oldRevision := sut revision.
	sut title: 'brand new title'.
	self should: sut revision = (oldRevision + 1).! !

XpfTestCase subclass: #XpfTaskTest
	instanceVariableNames: 'testProject testUserStory sut testIteration'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Tests-Server'!

!XpfTaskTest methodsFor: 'running' stamp: 'mt 4/16/2009 11:22'!
setUp

	super setUp.
	testProject := XpfProject new title: 'testProject'.
	testIteration := testProject addIteration: (XpfIteration new title: 'testIteration').
	testUserStory := testIteration addNewUserStory: (Dictionary with: 'title' -> 'testUserStory').
	sut := XpfTask new title: 'test task'.
! !

!XpfTaskTest methodsFor: 'tests' stamp: 'mt 4/15/2009 17:16'!
testAttributes

	self
		shouldnt: sut isDone;
		checkAccessor: #title on: sut with: 'test task';
		checkAccessor: #timeEstimated on: sut with: 10;
		checkAccessor: #timeActual on: sut with: 12;
		checkAccessor: #isDone on: sut with: true.! !

!XpfTaskTest methodsFor: 'tests' stamp: 'mt 4/16/2009 15:39'!
testHasDevelopers

	| developer |
	developer := testProject attachDeveloper: (XpfUser addNewUser: (Dictionary with: 'login' -> 'alice')).
	
	self should: sut developers size = 0.
	testUserStory addTask: sut.

	sut attachDeveloper: developer.
	self
		should: sut developers size = 1;
		should: sut developersWithDeleted size = 1;
		should: (developer tasks includes: sut).
	
	sut detachDeveloper: developer.
	self
		should: sut developers size = 0;
		should: sut developersWithDeleted size = 0.

	sut delete.
	developer delete.! !

!XpfTaskTest methodsFor: 'tests' stamp: 'topa 4/3/2009 15:01'!
testIntroducedIsDone

	| oldValue |
	oldValue := sut isDone.
	sut isDone: nil. "this is the case in Old objects"
	
	self should: sut isDone not.	
	sut isDone: oldValue.! !

!XpfTaskTest methodsFor: 'tests' stamp: 'mt 4/15/2009 17:34'!
testNewAndDelete

	| oldCount |
	oldCount := testUserStory tasks size.

	testUserStory addTask: sut.
	self
		should: testUserStory tasks size = (oldCount + 1);
		should: (testUserStory tasks anySatisfy: [:each | each title = 'test task']);
		should: sut userStory = testUserStory;
		shouldnt: sut isDeleted.

	sut delete.
	self
		should: testUserStory tasks size = oldCount;
		should: sut userStory = testUserStory;
		should: sut isDeleted.! !

!XpfTaskTest methodsFor: 'tests' stamp: 'mt 3/16/2009 11:04'!
testNewFrom

	[XpfTask newFrom: Dictionary new.]
		on: Error
		do: [self fail].! !

!XpfTaskTest methodsFor: 'tests' stamp: 'cs 4/23/2009 14:05'!
testStartWork

	self
		shouldnt: sut isStarted;
		should: sut lastStarted isNil;
		should: sut timeActual isNil.	
	sut isStarted: true.
	self
		should: sut isStarted;
		should: sut lastStarted notNil;
		should: sut timeActual notNil.	! !

!XpfTaskTest methodsFor: 'tests' stamp: 'cs 4/23/2009 14:05'!
testStopWork

	sut
		isStarted: true;
		isStarted: false.
	self
		shouldnt: sut isStarted;
		shouldnt: sut lastStarted isNil;
		shouldnt: sut timeActual isNil.! !

!XpfTestCase class methodsFor: 'testing' stamp: 'topa 3/3/2009 18:42'!
isAbstract

 	^ self name = #XpfTestCase! !

!XpfTestCase methodsFor: 'test-helper' stamp: 'mt 4/6/2009 17:13'!
checkAccessor: aSelector on: aTargetObject with: anObject
	"test getter/setter aSelector of aTargetObject with anObject"
	
	aTargetObject perform: aSelector asMutator with: anObject.
	self should: (aTargetObject perform: aSelector) = anObject
		! !

!XpfTestCase methodsFor: 'test-helper' stamp: 'topa 2/12/2009 14:03'!
denyAccessor: aSelector on: aTargetObject with: anObject
	"test getter/setter aSelector of aTargetObject with anObject
	 that dont behave like plain accessors.
	"
	self
		shouldnt: (aTargetObject perform: aSelector) == anObject
		! !

!XpfTestCase methodsFor: 'running' stamp: 'mt 3/12/2009 13:05'!
setUp

	super setUp.
	
	XpfProject useTestData: true.
	XpfUser useTestData: true.
	
	XpfProject projects: Set new.
	XpfUser users: Set new.! !

!XpfTestCase methodsFor: 'running' stamp: 'mt 3/12/2009 13:07'!
tearDown
	
	XpfProject useTestData: false.
	XpfUser useTestData: false.
	
	super tearDown.! !

XpfTestCase subclass: #XpfUserStoryTest
	instanceVariableNames: 'testProject sut testIteration'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Tests-Server'!

!XpfUserStoryTest methodsFor: 'running' stamp: 'mt 4/16/2009 11:30'!
setUp

	super setUp.
	testProject := XpfProject new title: 'testProject'.
	testIteration := testProject addIteration: (XpfIteration new title: 'testIteration').
	sut := XpfUserStory new 						
		title: 'User Authentication';
		priority: 3;
		timeEstimated: 10.! !

!XpfUserStoryTest methodsFor: 'tests' stamp: 'mt 4/15/2009 17:19'!
testAttributes

	self
		checkAccessor: #title on: sut with: 'US + Tasks verwalten';
		checkAccessor: #priority on: sut with: 5;
		checkAccessor: #timeEstimated on: sut  with: 10;
		checkAccessor: #timeActual on: sut  with: 12. 
		
! !

!XpfUserStoryTest methodsFor: 'tests' stamp: 'mt 4/16/2009 15:33'!
testHasTasks

	| task userStoryCount |
	testIteration addUserStory: sut.
	userStoryCount := testIteration userStories size.
		
	self should: sut tasks size = 0.
	task := sut addTask: XpfTask new. 
	self 
		should: sut tasks size = 1	description: 'Task count for user story is invalid.';
		should: sut tasksWithDeleted size = 1;
		should: testIteration userStories size = userStoryCount;
		should: task userStory = sut;
		shouldnt: task isDeleted.
	
	task delete.
	self
		should: sut tasks size = 0;
		should: sut tasksWithDeleted size = 1;
		should: testIteration userStories size = userStoryCount;
		should: task isDeleted.

	sut delete.! !

!XpfUserStoryTest methodsFor: 'tests' stamp: 'cs 4/17/2009 11:30'!
testHistoryInitial

	self should: sut history size = 5.
	self should: sut history first action = #created.! !

!XpfUserStoryTest methodsFor: 'tests' stamp: 'mt 4/16/2009 12:35'!
testMoveTask

	| targetUS task |
	testProject addIteration: testIteration.
	testIteration addUserStory: sut.
	targetUS := testIteration addUserStory: XpfUserStory new.
	task := sut addTask: (XpfTask new title: 'testMoveTask').
	
	self
		should: targetUS tasks isEmpty;
		should: sut tasks first = task.
		
	targetUS addTask: task.
	
	self
		should: targetUS tasks first = task;
		should: sut tasks isEmpty.! !

!XpfUserStoryTest methodsFor: 'tests' stamp: 'mt 4/16/2009 11:39'!
testNewAndDelete

	| oldCount task |
	oldCount := testIteration userStories size.
	testIteration addUserStory: sut.
	task := sut addTask: XpfTask new.
	
	self
		should: testIteration userStories size = (oldCount + 1);
		should: (testIteration userStories anySatisfy: [:each | each title = sut title]);
		shouldnt: sut isDeleted;
		shouldnt: task isDeleted.

	sut delete.
	self 
		should: testIteration userStories size = oldCount;
		should: sut isDeleted;
		should: task isDeleted.! !

!XpfUserStoryTest methodsFor: 'tests' stamp: 'mt 3/16/2009 11:05'!
testNewFrom

	[XpfUserStory newFrom: Dictionary new.]
		on: Error
		do: [self fail].! !

XpfTestCase subclass: #XpfUserTest
	instanceVariableNames: 'sut testProject'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Tests-Server'!

!XpfUserTest class methodsFor: 'fixture-data' stamp: 'topa 3/3/2009 22:59'!
login

	^ 'test.user'! !

!XpfUserTest class methodsFor: 'fixture-data' stamp: 'topa 3/3/2009 22:59'!
password

	^ 'TEST'! !

!XpfUserTest methodsFor: 'running' stamp: 'mt 4/16/2009 13:20'!
setUp

	super setUp.
	sut := XpfUser new
				login: self class login;
				password: self class password.
	testProject :=  XpfProject new title: 'xpforums'.
	XpfProject addProject: testProject.! !

!XpfUserTest methodsFor: 'tests' stamp: 'mt 4/16/2009 13:18'!
testAddExistingProjectToUser
	"Add a project to the user. That project should exist."

	| projectCount globalProjectCount projectId |
	XpfProject addProject: testProject.
	projectId := testProject id.
	projectCount := sut projects size.
	globalProjectCount := XpfProject all size.
	
	sut attachProject: testProject.
	self
		should: testProject id = projectId;
		should: XpfProject all size = globalProjectCount;
		should: sut projects size = (projectCount + 1);
		should: (XpfProject all includes: testProject);
		should: (sut projects includes: testProject).
	
	sut detachProject: testProject.
	self
		should: testProject id = projectId;
		should: XpfProject all size = globalProjectCount;
		should: sut projects size = projectCount;
		should: (XpfProject all includes: testProject);
		shouldnt: (sut projects includes: testProject).
		! !

!XpfUserTest methodsFor: 'tests' stamp: 'mt 3/4/2009 14:02'!
testAttributes

	self
		checkAccessor: #login on: sut with: 'marcel.taeumel';
		checkAccessor: #userName on: sut with: 'Marcel Taeumel';
		checkAccessor: #email on: sut with: 'marcel.taeumel@student.hpi.uni-potsdam.de'.! !

!XpfUserTest methodsFor: 'tests' stamp: 'mt 4/16/2009 15:42'!
testHasProjects
	| projectCount globalProjectCount |
	projectCount := sut projects size.
	globalProjectCount := XpfProject all size.
	
	sut attachProject: testProject.
	self
		should: testProject id notNil;
		should: XpfProject all size = globalProjectCount;
		should: sut projects size = (projectCount + 1);
		should: sut projectsWithDeleted size = (projectCount + 1);
		should: (XpfProject all includes: testProject);
		should: (sut projects includes: testProject).
	
	sut detachProject: testProject.
	self
		should: XpfProject all size = globalProjectCount;
		should: sut projects size = projectCount;
		should: sut projectsWithDeleted size = projectCount;		
		should: (XpfProject all includes: testProject);
		shouldnt: (sut projects includes: testProject).
		! !

!XpfUserTest methodsFor: 'tests' stamp: 'mt 4/6/2009 15:04'!
testNewAndDelete

	| oldCount |	
	oldCount := XpfUser all size.	
	self shouldnt: (XpfUser all anySatisfy: [ :each | each login = sut login]).

	XpfUser addUser: sut.
	self 
		should: XpfUser all size = (oldCount + 1);
		should: (XpfUser all anySatisfy: [ :each | each login = sut login]);
		shouldnt: sut isDeleted.
	
	sut delete.
	self
		should: XpfUser all size = oldCount;
		should: sut isDeleted.! !

!XpfUserTest methodsFor: 'tests' stamp: 'mt 3/16/2009 11:04'!
testNewFrom

	| done |
	[XpfUser newFrom: (Dictionary newFrom: {'login'->'test@example.com'}).]
		on: Error
		do: [self fail].
	
	[XpfUser newFrom: Dictionary new. done := true]
		on: Error
		do: [done := false].

	self shouldnt: done.! !

!XpfUserTest methodsFor: 'tests' stamp: 'mt 3/6/2009 14:05'!
testPasswordHashing

	self
		"shouldnt: (sut respondsTo: #password);"
		should: sut password = nil;
		should: (sut authenticateBy: self class password);
		shouldnt: (sut authenticateBy: self class password , 'NOT').
		! !

!XpfUserTest methodsFor: 'tests' stamp: 'mt 4/6/2009 15:04'!
testUserAuthenticationFail

	XpfUser addUser: sut.
	self
		should: (XpfUser authenticate: self class login             by: self class password , 'NOT' ) isNil;
		should: (XpfUser authenticate: self class login , 'NOT' by: self class password             ) isNil;
		should: (XpfUser authenticate: self class login , 'NOT' by: self class password , 'NOT') isNil.
	sut delete.! !

!XpfUserTest methodsFor: 'tests' stamp: 'mt 4/6/2009 15:05'!
testUserAuthenticationSuccess

	XpfUser addUser: sut.
	self should: sut = (XpfUser authenticate: self class login by: self class password).
	sut delete.! !

!XpfUserTest methodsFor: 'tests' stamp: 'topa 4/27/2009 14:18'!
testUserIsOnline

	| t1 t2 t3 |
	t1 := TimeStamp now.
	t2 := t1 - 5 seconds.
	t3 := t1 - 15 seconds.
	
	sut lastAccess: t2.
	self 	should: sut isOnline.
		
	sut lastAccess: t3.
	self shouldnt: sut isOnline.! !
